/// <reference types="react" />
export type PopupPosition = 'top' | 'bottom' | 'left' | 'right' | 'center';
export interface IProps {
    /**
     * @description.zh 类名
     * @description.en class name
     */
    className?: string;
    /**
     * @description.zh 是否显示弹出层
     * @description.en Is show popup
     * @default false
     */
    show?: boolean;
    /**
     * @description.zh 动画时长，单位毫秒
     * @description.en Animation duration, in milliseconds
     * @default 300
     */
    duration?: number;
    /**
     * @description.zh popup 层级
     * @description.en popup level
     * @default 1000
     */
    zIndex?: number;
    /**
     * @description.zh 是否显示遮罩层
     * @description.en Is show overlay
     * @default true
     */
    overlay?: boolean;
    /**
     * @description.zh 点击弹出层时触发
     * @description.en Triggered when the popup layer is clicked
     */
    onClickOverlay?: (event: any) => any;
    /**
     * @description.zh 是否在点击遮罩层后关闭
     * @description.en Whether to close after clicking the mask layer
     * @default false
     */
    closeOnClickOverlay?: boolean;
    /**
     * @description.zh 弹出位置
     * @description.en popup position
     * @default 'bottom'
     */
    position?: 'top' | 'bottom' | 'left' | 'right' | 'center';
    /**
     * @description.zh 是否显示圆角
     * @description.en Whether to display rounded corners
     * @default false
     */
    round?: boolean;
    /**
     * @description.zh 是否显示关闭图标
     * @description.en Is show close Icon
     * @default false
     */
    closeable?: boolean;
    /**
     * @description.zh 关闭图标图片地址，从 2.0.0 版本开始不再支持传入 IconFontName
     * @description.en close icon image link, from version 2.0.0, IconFontName is no longer supported
     * @default "icon-cancel"
     */
    closeIcon?: string;
    /**
     * @description.zh 关闭图标样式
     * @description.en Custom close icon style
     * @default {}
     */
    closeIconStyle?: React.CSSProperties;
    /**
     * @description.zh 关闭图标的位置
     * @description.en  The position of close icon
     * @default 'top-right'
     */
    closeIconPosition?: 'top-left' | 'top-right' | 'bottom-left' | 'bottom-right';
    /**
     * @description.zh 蒙层关闭触发的方法
     * @description.en event when click close icon
     */
    onClose?: (event: any) => any;
    /**
     * @description.zh 是否为 iPhoneX 留出底部安全距离
     * @description.en Keep a safe distance from the bottom
     * @default false
     */
    safeAreaInsetBottom?: boolean;
    /**
     * @description.zh 是否留出顶部安全距离（状态栏高度）
     * @description.en Whether to leave a top safety distance (status bar height)
     * @default false
     */
    safeAreaInsetTop?: boolean;
    /**
     * @description.zh 自定义遮罩层样式
     * @description.en Custom overlay style
     */
    overlayStyle?: React.CSSProperties;
    /**
     * @description.zh 样式
     * @description.en Style
     */
    customStyle?: React.CSSProperties;
    /**
     * @description.zh 子元素
     * @description.en children element
     */
    children?: React.ReactNode;
}
export declare const defaultProps: IProps;
